# Module: tide.backend_utils

Internal backend interop and C/CUDA bindings.
TODO: Document usage and expected types if exposed.

## Functions
- is_backend_available
- get_dll
- get_maxwell_tm_forward_template
- get_maxwell_tm_backward_template
- get_maxwell_tm_forward_with_storage_template
- get_maxwell_tm_forward_with_boundary_storage_template
- get_maxwell_tm_backward_with_boundary_template
- get_backend_function
- tensor_to_ptr
- ensure_contiguous
